@@ -1,8 +1,8 @@
 loadMessage <- function()
 {
   cat("\n")
-  ver <-packageDescription("SASxport", fields="Version") 
-  date <- packageDescription("SASxport", fields="Date") 
+  ver <-packageDescription("SASxport", fields="Version")
+  date <- packageDescription("SASxport", fields="Date")
   cat("Loaded SASxport version ", ver,  " (", date ,").\n", sep="")
   cat("\n")
   cat("  Updates and technical support available from Random Technologies, LLC\n")
@@ -12,13 +12,6 @@ loadMessage <- function()
   cat("\n")
 }
 
-
-
-.First.lib <- function(lib, pkg) {
-  library.dynam("SASxport", pkg, lib)
-  loadMessage()
-}
-
 .onLoad <- function(lib, pkg) {
   loadMessage()
 }
